summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/private/legacy/OC_Helper.php8
-rw-r--r--lib/private/legacy/OC_Util.php2
2 files changed, 5 insertions, 5 deletions
diff --git a/lib/private/legacy/OC_Util.php b/lib/private/legacy/OC_Util.php
index 88cd6baddc5..0130d503a89 100644
--- a/lib/private/legacy/OC_Util.php
+++ b/lib/private/legacy/OC_Util.php
@@ -158,7 +158,7 @@ class OC_Util {
* Get the quota of a user
*
* @param IUser|null $user
- * @return int|\OCP\Files\FileInfo::SPACE_UNLIMITED|false Quota bytes
+ * @return float|\OCP\Files\FileInfo::SPACE_UNLIMITED|false Quota bytes
*/
public static function getUserQuota(?IUser $user) {
if (is_null($user)) {
diff --git a/lib/private/legacy/OC_Helper.php b/lib/private/legacy/OC_Helper.php
index 3b409fd1d04..de42a7bc7fc 100644
--- a/lib/private/legacy/OC_Helper.php
+++ b/lib/private/legacy/OC_Helper.php
@@ -95,7 +95,7 @@ class OC_Helper {
/**
* Make a computer file size
* @param string $str file size in human readable format
* @return int|false a file size in bytes
*
* Makes 2kB to 2048.
*
@@ -104,7 +104,7 @@ class OC_Helper {
public static function computerFileSize($str) {
$str = strtolower($str);
if (is_numeric($str)) {
- return (int)$str;
+ return (float)$str;
}
$bytes_array = [
@@ -131,7 +131,7 @@ class OC_Helper {
$bytes = round($bytes);
- return (int)$bytes;
+ return $bytes;
}
/**
@@ -577,7 +577,7 @@ class OC_Helper {
/**
* Get storage info including all mount points and quota
*/
- private static function getGlobalStorageInfo(int $quota, IUser $user, IMountPoint $mount): array {
+ private static function getGlobalStorageInfo(float $quota, IUser $user, IMountPoint $mount): array {
$rootInfo = \OC\Files\Filesystem::getFileInfo('', 'ext');
$used = $rootInfo['size'];
if ($used < 0) {
@@ -95,7 +95,7 @@ class OC_Helper {
* Make a computer file size
* @param string $str file size in human readable format
- * @return int|false a file size in bytes
+ * @return float|false a file size in bytes
*
* Makes 2kB to 2048.